@@ -331,6 +331,20 @@ static PyObject* Connection_copy_from_csv(PyObject* self, PyObject* args, PyObje
     if (PQputCopyEnd(cnxn->pgconn, 0) != 1)
         return SetConnectionError(cnxn);
 
+    // After a copy, you have to get another result to know if it was successful.
+
+    ResultHolder final_result;
+    ExecStatusType status = PGRES_COMMAND_OK;
+    Py_BEGIN_ALLOW_THREADS
+    final_result = PQgetResult(cnxn->pgconn);
+    status = PQresultStatus(final_result);
+    Py_END_ALLOW_THREADS
+
+    if (status != PGRES_COMMAND_OK) {
+      // SetResultError will take ownership of `result`.
+      return SetResultError(final_result.Detach());
+    }
+
     Py_RETURN_NONE;
 }
 
