@@ -52,7 +52,7 @@ def _test_strtype(cnxn, sqltype, value, resulttype=None, colsize=None):
 
     cnxn.execute(sql)
     cnxn.execute("insert into t1 values($1)", value)
-    v = cnxn.scalar("select * from t1")
+    v = cnxn.fetchval("select * from t1")
     assert type(v) == resulttype
 
     if value is not None:
@@ -159,7 +159,7 @@ def _datapath(filename):
 def test_copy_csv(cnxn):
     cnxn.execute("create table t1(a int, b varchar(20))")
     cnxn.copy_from_csv("t1", open(_datapath('test-noheader.csv')))
-    assert cnxn.scalar("select count(*) from t1") == 2
+    assert cnxn.fetchval("select count(*) from t1") == 2
     row = cnxn.fetchrow("select a,b from t1 where a=2")
     assert row.a == 2
     assert row.b == 'two'
@@ -168,16 +168,26 @@ def test_copy_csv(cnxn):
 def test_copy_csv_header(cnxn):
     cnxn.execute("create table t1(a int, b varchar(20))")
     cnxn.copy_from_csv("t1", open(_datapath('test-header.csv')), header=True)
-    assert cnxn.scalar("select count(*) from t1") == 2
+    assert cnxn.fetchval("select count(*) from t1") == 2
     row = cnxn.fetchrow("select a,b from t1 where a=2")
     assert row.a == 2
     assert row.b == 'two'
 
 
+def test_copy_csv_error(cnxn):
+    """
+    Ensure an error copying raises a Python error.
+    """
+    # We'll make the second column too small.
+    cnxn.execute("create table t1(a int, b varchar(1) not null)")
+    with pytest.raises(pglib.Error):
+        cnxn.copy_from_csv("t1", open(_datapath('test-noheader.csv')))
+
+
 def test_copy_csv_gzip(cnxn):
     cnxn.execute("create table t1(a int, b varchar(20))")
     cnxn.copy_from_csv("t1", gzip.open(_datapath('test-header.csv.gz')), header=True)
-    assert cnxn.scalar("select count(*) from t1") == 2
+    assert cnxn.fetchval("select count(*) from t1") == 2
     row = cnxn.fetchrow("select a,b from t1 where a=2")
     assert row.a == 2
     assert row.b == 'two'
@@ -311,7 +321,7 @@ def test_rset_nonzero(cnxn):
 
 def test_fetchval_zero(cnxn):
     """
-    Ensure cnxn.scalar() returns None if no rows are selected.
+    Ensure cnxn.fetchval() returns None if no rows are selected.
     """
     cnxn.execute("create table t1(a int)")
     value = cnxn.fetchval("select a from t1")
@@ -815,7 +825,7 @@ def test_rset_colinfos(cnxn):
         ('b', 'text'),
         ('c', 'date'),
         ('d', 'timestamptz'),
-        ('e', 'decimal'),
+        ('e', 'numeric'),
     ]
 
     for actual, expected in zip(rset.colinfos, expected_infos):
